@@ -113,9 +113,9 @@ def ProcessAlarm():
     elif(now>=records.AlarmTimeWindowEnd_seconds): #End of alarm time window, set alarm off anyway
         if(records.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
             print "************ ALARM ALARM (End of Alarm Time Window)"
-            records.AlarmTime_tuple=time.localtime()#set to now (just for record)
-            records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple) 
-            records.Trigger=data.Trigger #update Trigger level on alarm occurence
+#            records.AlarmTime_tuple=time.localtime()#set to now (just for record)
+#            records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple) 
+#            records.Trigger=data.Trigger #update Trigger level on alarm occurence
             data.AlarmIsActive=True
 
 #    print "records.AlarmIsSet", records.AlarmIsSet 
